@@ -1,6 +1,6 @@
 package Hubot::Adapter::Irc;
 {
-  $Hubot::Adapter::Irc::VERSION = '0.0.5';
+  $Hubot::Adapter::Irc::VERSION = '0.0.6';
 }
 use Moose;
 use namespace::autoclean;
@@ -38,15 +38,15 @@ sub join {
     my ( $self, $channel ) = @_;
     $self->irc->send_srv( JOIN => $channel );
 }
-sub part       { }
-sub kick       { }
-sub command    { }
+sub part    { }
+sub kick    { }
+sub command { }
 
 sub parse_msg {
     my ( $self, $irc_msg ) = @_;
 
     my ($nickname) = $irc_msg->{prefix} =~ m/^([^!]+)/;
-    my $message = decode_utf8($irc_msg->{params}[1]);
+    my $message = decode_utf8( $irc_msg->{params}[1] );
     return ( $nickname, $message );
 }
 
@@ -102,17 +102,13 @@ sub run {
         join => sub {
             my ( $cl, $nick, $channel, $is_myself ) = @_;
             print "joined $channel\n";
-            my $user = $self->createUser($channel, $nick);
-            $self->receive(
-                new Hubot::EnterMessage(
-                    user => $user
-                )
-            );
+            my $user = $self->createUser( $channel, $nick );
+            $self->receive( new Hubot::EnterMessage( user => $user ) );
         },
         publicmsg => sub {
             my ( $cl, $channel, $ircmsg ) = @_;
             my ( $nick, $msg ) = $self->parse_msg($ircmsg);
-            my $user = $self->createUser($channel, $nick);
+            my $user = $self->createUser( $channel, $nick );
             $self->receive(
                 new Hubot::TextMessage(
                     user => $user,
@@ -120,6 +116,20 @@ sub run {
                 )
             );
         },
+        privatemsg => sub {
+            my ( $cl, $nick, $ircmsg ) = @_;
+            my $msg = ( $self->parse_msg($ircmsg) )[1];
+            my ($channel) = $msg =~ m/^\#/ ? split / /, $msg : split /,/,
+              $ENV{HUBOT_IRC_ROOMS};
+            $msg =~ s/^$channel\s*//;
+            my $user = $self->createUser( $channel, $nick );
+            $self->receive(
+                new Hubot::WhisperMessage(
+                    user => $user,
+                    text => $msg,
+                )
+            );
+        },
         part => sub {
             my ( $nick, $channel, $is_myself, $msg ) = @_;
         },
@@ -149,7 +159,7 @@ sub close {
 }
 
 sub createUser {
-    my ($self, $channel, $from) = @_;
+    my ( $self, $channel, $from ) = @_;
     my $user = $self->userForName($from);
     unless ($user) {
         my $id = time;
