@@ -1,6 +1,6 @@
 package Hubot::Robot;
 {
-  $Hubot::Robot::VERSION = '0.0.5';
+  $Hubot::Robot::VERSION = '0.0.6';
 }
 
 use Moose;
@@ -234,6 +234,15 @@ sub leave {
     ));
 }
 
+sub whisper {
+    my ($self, $callback) = @_;
+    $self->addListener(Hubot::Listener->new(
+        robot => $self,
+        matcher => sub { ref(shift) eq 'Hubot::WhisperMessage' ? 1 : () },
+        callback => $callback
+    ));
+}
+
 sub catchAll {
     my ($self, $callback) = @_;
     $self->addListener(Hubot::Listener->new(
